Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolAnnotationParser");
;//5.0.1-v7 Mon Jan 19 20:38:07 CST 2026
